==> AnnBuilder_1.3.3.tar.gz: AnnBuilder/R/chrLocPkgBuilder.R <==
# Building a data package containing location data for genes on
# chromosomes
chrLocPkgBuilder <- function(pkgName = "humanCHRLOC", pkgPath, version,
                             author, organism = "human",
                             url = getSrcUrl("gp", "human")){

    chrLoc <- getChroLocation(url, raw = TRUE)
    suffix <- gsub(".*_random", "Unconfident", chrLoc[,2])
    suffix[suffix != "Unconfident" | is.na(suffix)] <- "Confident"
    chrLoc <- cbind(chrLoc[,1], gsub("_random", "", chrLoc[,2]),
                    chrLoc[,3], paste(chrLoc[, 4], suffix, sep = "@"),
                    paste(chrLoc[, 5], suffix, sep = "@"))
#    chrLength <- findChrLength(organism)
    makeSrcInfo()
    createEmptyDPkg(pkgName, pkgPath)
    # Write the mappings between LL and chromosome number
    ll2Chr <- mergeRowByKey(chrLoc[, 1:2])
    env <- new.env(hash = TRUE, parent = NULL)
    multiassign(ll2Chr[,1], lapply(ll2Chr[,2], splitEntry), env)
    assign(paste(pkgName, "LOCUSID2CHR", sep = ""), env)
    save(list = paste(pkgName, "LOCUSID2CHR", sep = ""),
         file =  file.path(pkgPath, pkgName, "data",
         paste(pkgName, "LOCUSID2CHR.rda", sep = "")))
    writeManPage(pkgName, pkgPath, "LOCUSID2CHR",
                         src = get("LOCUSID2CHR", AnnInfo)$src)
    # Write the tamplates for man pages
    writeManPage(pkgName, pkgPath, "#CHRNUM#START", "human",
                         src = get("#CHRNUM#START", AnnInfo)$src)
    writeManPage(pkgName, pkgPath, "#CHRNUM#END", "human",
                         src = get("#CHRNUM#END", AnnInfo)$src)
    for(i in getChrNum(unique(chrLoc[,2]))){
        chr4Org <- chrLoc[chrLoc[,2] == i,]
        # Remove <NA>s introduced by the above manipulation
        chr4Org <- chr4Org[!is.na(chr4Org[,1]), ]
        # For -strand start should be end and end should be start
        chr4Org <- rbind(chr4Org[chr4Org[, 3] == "+", c(1, 4, 5)],
                         chr4Org[chr4Org[, 3] == "-", c(1, 5, 4)] )

        # Collapse values for LocusLink ids
        chr4Org <- mergeRowByKey(chr4Org)
        env <- new.env(hash = TRUE, parent = NULL)
        multiassign(chr4Org[, 1], lapply(chr4Org[, 2],
                                       twoStepSplit, asNumeric = TRUE), env)
        assign(paste(pkgName, i, "START", sep = ""), env)
        save(list = paste(pkgName, i, "START", sep = ""),
             file =  file.path(pkgPath, pkgName, "data",
             paste(pkgName, i, "START.rda", sep = "")))
        env <- new.env(hash = TRUE, parent = NULL)
        multiassign(chr4Org[, 1],
                        lapply(chr4Org[, 3], twoStepSplit,
                               asNumeric = TRUE), env)
        assign(paste(pkgName, i, "END", sep = ""), env)
        save(list = paste(pkgName, i, "END", sep = ""),
             file =  file.path(pkgPath, pkgName, "data",
             paste(pkgName, i, "END.rda", sep = "")))
        copySubstitute(file.path(pkgPath, pkgName, "man",
                           paste(pkgName, "#CHRNUM#START.Rd", sep = "")),
                           file.path(pkgPath, pkgName,
                           "man", paste(pkgName, i, "START.Rd",
                                        sep = "")), list(CHRNUM = i), "#")
        copySubstitute(file.path(pkgPath, pkgName, "man",
                           paste(pkgName, "#CHRNUM#END.Rd", sep = "")),
                           file.path(pkgPath, pkgName,
                           "man", paste(pkgName, i, "END.Rd",
                                        sep = "")), list(CHRNUM = i), "#")
    }
     # Remove man page templates
    file.remove(file.path(pkgPath, pkgName, "man",
                           paste(pkgName, "#CHRNUM#START.Rd", sep = "")),
                file.path(pkgPath, pkgName, "man",
                           paste(pkgName, "#CHRNUM#END.Rd", sep = "")))
    writeDescription(pkgName, pkgPath, version, author)
    # using pkgName() and the man page for the function
    writeFun (pkgPath, pkgName, organism = organism)
    writeMan4Fun(pkgName, pkgPath)
    # Write .First.lib
    writeZZZ(pkgPath, pkgName)
    # Write the quality control data
    # Quality control
    getDPStats("", pkgName, pkgPath)
    writeMan4QC(pkgName, pkgPath)
#    writeOrganism(pkgName, pkgPath, organism)
#    writeManPage(pkgName, pkgPath, "ORGANISM",
#                         src = get("ORGANISM", AnnInfo)$src)
}
# Chromosome number may have _random extensions for genes not too sure
# about their locations. Remove them
getChrNum <- function(chr){
    options(warn = -1)
    keep <- chr[!is.na(as.numeric(chr))]
    options(warn = 1)
    keep <- c(keep, chr[is.element(chr, c("X", "Y"))])
    return(keep)
}

==> AnnBuilder_1.4.2.tar.gz: AnnBuilder/R/chrLocPkgBuilder.R <==
# Building a data package containing location data for genes on
# chromosomes
chrLocPkgBuilder <- function(pkgName = "humanCHRLOC", pkgPath, version,
                             author, organism = "human",
                             url = getSrcUrl("gp", organism)){

    chrLoc <- getChroLocation(url, raw = TRUE)
    suffix <- gsub(".*_random", "Unconfident", chrLoc[,2])
    suffix[suffix != "Unconfident" | is.na(suffix)] <- "Confident"
    chrLoc <- cbind(chrLoc[,1], gsub("_random", "", chrLoc[,2]),
                    chrLoc[,3], paste(chrLoc[, 4], suffix, sep = "@"),
                    paste(chrLoc[, 5], suffix, sep = "@"))
    # Put signs for - strands
    chrLoc[, 4] <- gsub("\\+", "", paste(chrLoc[,3], chrLoc[,4], sep = ""))
    chrLoc[, 5] <- gsub("\\+", "", paste(chrLoc[,3], chrLoc[,5], sep = ""))
#    chrLength <- findChrLength(organism)
    makeSrcInfo()
    createEmptyDPkg(pkgName, pkgPath)
    # Write the mappings between LL and chromosome number
    ll2Chr <- mergeRowByKey(chrLoc[, 1:2])
    env <- new.env(hash = TRUE, parent = NULL)
    multiassign(ll2Chr[,1], lapply(ll2Chr[,2], splitEntry), env)
    assign(paste(pkgName, "LOCUSID2CHR", sep = ""), env)
    save(list = paste(pkgName, "LOCUSID2CHR", sep = ""),
         file =  file.path(pkgPath, pkgName, "data",
         paste(pkgName, "LOCUSID2CHR.rda", sep = "")))
    writeManPage(pkgName, pkgPath, "LOCUSID2CHR",
                         src = get("LOCUSID2CHR", AnnInfo)$src)
    # Write the tamplates for man pages
    writeManPage(pkgName, pkgPath, "#CHRNUM#START", "human",
                         src = get("#CHRNUM#START", AnnInfo)$src)
    writeManPage(pkgName, pkgPath, "#CHRNUM#END", "human",
                         src = get("#CHRNUM#END", AnnInfo)$src)
    for(i in getChrNum(unique(chrLoc[,2]))){
        chr4Org <- chrLoc[chrLoc[,2] == i,]
        # Remove <NA>s introduced by the above manipulation
        chr4Org <- chr4Org[!is.na(chr4Org[,1]), ]
        # For -strand start should be end and end should be start
        # chr4Org <- rbind(chr4Org[chr4Org[, 3] == "+", c(1, 4, 5)],
        #                 chr4Org[chr4Org[, 3] == "-", c(1, 5, 4)] )
        chr4Org <- chr4Org[, c(1,4,5)]
        # Collapse values for LocusLink ids
        chr4Org <- mergeRowByKey(chr4Org)
        env <- new.env(hash = TRUE, parent = NULL)
        multiassign(chr4Org[, 1], lapply(chr4Org[, 2],
                                       twoStepSplit, asNumeric = TRUE), env)
        assign(paste(pkgName, i, "START", sep = ""), env)
        save(list = paste(pkgName, i, "START", sep = ""),
             file =  file.path(pkgPath, pkgName, "data",
             paste(pkgName, i, "START.rda", sep = "")))
        env <- new.env(hash = TRUE, parent = NULL)
        multiassign(chr4Org[, 1],
                        lapply(chr4Org[, 3], twoStepSplit,
                               asNumeric = TRUE), env)
        assign(paste(pkgName, i, "END", sep = ""), env)
        save(list = paste(pkgName, i, "END", sep = ""),
             file =  file.path(pkgPath, pkgName, "data",
             paste(pkgName, i, "END.rda", sep = "")))
        copySubstitute(file.path(pkgPath, pkgName, "man",
                           paste(pkgName, "#CHRNUM#START.Rd", sep = "")),
                           file.path(pkgPath, pkgName,
                           "man", paste(pkgName, i, "START.Rd",
                                        sep = "")), list(CHRNUM = i), "#")
        copySubstitute(file.path(pkgPath, pkgName, "man",
                           paste(pkgName, "#CHRNUM#END.Rd", sep = "")),
                           file.path(pkgPath, pkgName,
                           "man", paste(pkgName, i, "END.Rd",
                                        sep = "")), list(CHRNUM = i), "#")
    }
    saveCytoband(pkgName, pkgPath, organism, url, ext = "cytoBand.txt.gz")
    # Remove man page templates
    file.remove(file.path(pkgPath, pkgName, "man",
                           paste(pkgName, "#CHRNUM#START.Rd", sep = "")),
                file.path(pkgPath, pkgName, "man",
                           paste(pkgName, "#CHRNUM#END.Rd", sep = "")))
    writeDescription(pkgName, pkgPath, version, author)
    # using pkgName() and the man page for the function
    writeFun (pkgPath, pkgName, organism = organism)
    writeMan4Fun(pkgName, pkgPath)
    # Write .First.lib
    writeZZZ(pkgPath, pkgName)
    # Write the quality control data
    # Quality control
    getDPStats("", pkgName, pkgPath)
    writeMan4QC(pkgName, pkgPath)
#    writeOrganism(pkgName, pkgPath, organism)
#    writeManPage(pkgName, pkgPath, "ORGANISM",
#                         src = get("ORGANISM", AnnInfo)$src)
}
# Chromosome number may have _random extensions for genes not too sure
# about their locations. Remove them
getChrNum <- function(chr){
    options(warn = -1)
    keep <- chr[!is.na(as.numeric(chr))]
    options(warn = 1)
    keep <- c(keep, chr[is.element(chr, c("X", "Y"))])
    return(keep)
}

saveCytoband <- function(pkgName, pkgPath, organism, url,
                         ext = "cytoBand.txt.gz"){
    cytoband <- getCytoLoc(organism, srcUrl = paste(url, ext, sep = ""))
    saveList(cytoband, pkgName, pkgPath, "CYTOLOC")
    writeManPage(pkgName, pkgPath, "CYTOLOC", organism = organism,
                 src = "gp", isEnv = FALSE)
}
